
# Don't display everything
.SILENT:


# Check config.h file name
ifndef config_h
 config_h := config.h
endif


# Check config.mk file name
ifndef config_mk
 config_mk := config.mk
endif


# Check for a /bin/sh type shell
ifeq ($(findstring bin/, $(SHELL)), bin/)

  include unix/tools.mk

  # Most likely bash compatible
  # Do more tests if you need to
  ifeq ($(findstring bash, $(SHELL)), bash)
   # something bash specific
  endif

else

 # Window's echo command writes the (") around the text to the file.
 # Using version 4.0+ of make the echo's can be replaced with $(file ...)
 $(error This version of autoconfig.mk requires a bash compatible shell)

 # Check for cmd shell
 ifeq ($(findstring cmd.exe, $(COMSPEC)), cmd.exe)

  include windows/tools.mk

 endif
endif


# Check for posix compatibility
ifeq ($(findstring Darwin, $(SYSTEM)), Darwin)
 posix = 1
endif
ifeq ($(findstring FreeBSD, $(SYSTEM)), FreeBSD)
 posix = 1
endif
ifeq ($(findstring Linux, $(SYSTEM)), Linux)
 posix = 1
endif
ifeq ($(findstring CYGWIN, $(SYSTEM)), CYGWIN)
 posix = 1
endif


# Check for windows compatibility
ifeq ($(findstring MINGW, $(SYSTEM)), MINGW)
 win = 1
endif
ifeq ($(findstring Windows, $(COMSPEC)), Windows)
 win = 1
endif


# Write configuration files
config:
	echo "Generating configuration files"
	$(CP) config.h.in $(config_h)

	echo "System            $(SYSTEM)"
	echo "#ifndef SYSTEM" >> $(config_h)
	echo "#define SYSTEM		\"$(SYSTEM)\"" >> $(config_h)
	echo "#endif" >> $(config_h)
	echo >> $(config_h)
	echo > $(config_mk)
	echo "SYSTEM := $(SYSTEM)" >> $(config_mk)

# Use POSIX
ifdef posix
	echo "POSIX:            true"
	echo "#ifndef POSIX" >> $(config_h)
	echo "#define POSIX		1" >> $(config_h)
	echo "#endif" >> $(config_h)
	echo >> $(config_h)
	echo "POSIX := 1" >> $(config_mk)
else
 # Use Windows
 ifdef win
	echo "Windows:          true"
	echo "#ifndef WINDOWS" >> $(config_h)
	echo "#define WINDOWS		1" >> $(config_h)
	echo "#endif" >> $(config_h)
	echo >> $(config_h)
	echo "WINDOWS := 1" >> $(config_mk)
 endif
endif

# Use Unix tools
ifeq ($(findstring bin/, $(SHELL)), bin/)
	echo "Unix tools:       true"
	echo "include unix/tools.mk" >> $(config_mk)
else
 # Use Windows tools
 ifeq ($(findstring cmd.exe, $(SHELL)), cmd.exe)
	echo "Windows tools:    true"
	echo "include windows/tools.mk" >> $(config_mk)
 endif
endif

	echo "#endif	// CONFIG_H" >> $(config_h)
